#[non_exhaustive]pub enum SignatureFailure {
Malformed,
Invalid,
}Expand description
Why a signature failed to verify.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Malformed
The signature bytes are the wrong length or shape for the algorithm.
Invalid
The signature parsed correctly but did not verify against the data.